@@ -9,8 +9,7 @@ log = logging.getLogger(__name__)
 
 
 class Http(Rpc):
-    """ RPC Calls
-    """
+    """RPC Calls"""
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -24,10 +23,10 @@ class Http(Rpc):
         await self.session.close()
 
     async def rpcexec(self, payload):
-        """ Execute a RPC call
+        """Execute a RPC call
 
-            :param dict payload: json-rpc request in format:
-                {"jsonrpc": "2.0", "method": "call", "params": "[x, y, z]", "id": 1}
+        :param dict payload: json-rpc request in format:
+            {"jsonrpc": "2.0", "method": "call", "params": "[x, y, z]", "id": 1}
         """
         async with self.session.post(self.url, json=payload) as response:
             response_text = await response.text()
