@@ -54,11 +54,11 @@ class Base58(Prefix):
             raise ValueError("Error loading Base58 object: {}".format(data))
 
     def __format__(self, _format):
-        """ Format output according to argument _format (wif,...)
+        """Format output according to argument _format (wif,...)
 
-            :param str _format: Format to use
-            :return: formatted data according to _format
-            :rtype: str
+        :param str _format: Format to use
+        :return: formatted data according to _format
+        :rtype: str
 
         """
         if _format.upper() == "WIF":
@@ -71,26 +71,26 @@ class Base58(Prefix):
             return _format.upper() + str(self)
 
     def __repr__(self):
-        """ Returns hex value of object
+        """Returns hex value of object
 
-            :return: Hex string of instance's data
-            :rtype: hex string
+        :return: Hex string of instance's data
+        :rtype: hex string
         """
         return self._hex
 
     def __str__(self):
-        """ Return graphene-base58CheckEncoded string of data
+        """Return graphene-base58CheckEncoded string of data
 
-            :return: Base58 encoded data
-            :rtype: str
+        :return: Base58 encoded data
+        :rtype: str
         """
         return gphBase58CheckEncode(self._hex)
 
     def __bytes__(self):
-        """ Return raw bytes
+        """Return raw bytes
 
-            :return: Raw bytes of instance
-            :rtype: bytes
+        :return: Raw bytes of instance
+        :rtype: bytes
 
         """
         return unhexlify(self._hex)
@@ -137,9 +137,17 @@ def base58encode(hexstring):
 
 
 def ripemd160(s):
-    ripemd160 = hashlib.new("ripemd160")
-    ripemd160.update(unhexlify(s))
-    return ripemd160.digest()
+    try:
+        ripemd160 = hashlib.new("ripemd160")
+        ripemd160.update(unhexlify(s))
+        return ripemd160.digest()
+    except ValueError:
+        # ripemd160 is not guaranteed to be available in hashlib on all platforms.
+        # See for reference https://github.com/bitcoin/bitcoin/issues/23710
+        # We bundle a pure python implementation as fallback that gets used now:
+        from .ripemd160 import ripemd160
+
+        return ripemd160(unhexlify(s))
 
 
 def doublesha256(s):
