@@ -12,8 +12,7 @@ operations = {o: ops.index(o) for o in ops}
 
 
 def getOperationNameForId(i: int):
-    """ Convert an operation id into the corresponding string
-    """
+    """Convert an operation id into the corresponding string"""
     assert isinstance(i, (int)), "This method expects an integer argument"
     for key in operations:
         if int(operations[key]) is int(i):
@@ -22,8 +21,8 @@ def getOperationNameForId(i: int):
 
 
 def getOperationName(id: str):
-    """ This method returns the name representation of an operation given
-        its value as used in the API
+    """This method returns the name representation of an operation given
+    its value as used in the API
     """
     if isinstance(id, str):
         # Some graphene chains (e.g. steem) do not encode the
