@@ -12,32 +12,32 @@ log = logging.getLogger()
 
 
 class Account(BlockchainObject, SyncAccount):
-    """ This class allows to easily access Account data
+    """This class allows to easily access Account data
 
-        :param str account_name: Name of the account
-        :param instance blockchain_instance: instance to use when accesing a RPC
-        :param bool full: Obtain all account data including orders, positions, etc.
-        :param bool lazy: Use lazy loading
-        :param bool full: Obtain all account data including orders, positions,
-               etc.
-        :returns: Account data
-        :rtype: dictionary
-        :raises .exceptions.AccountDoesNotExistsException: if account
-                does not exist
+    :param str account_name: Name of the account
+    :param instance blockchain_instance: instance to use when accesing a RPC
+    :param bool full: Obtain all account data including orders, positions, etc.
+    :param bool lazy: Use lazy loading
+    :param bool full: Obtain all account data including orders, positions,
+           etc.
+    :returns: Account data
+    :rtype: dictionary
+    :raises .exceptions.AccountDoesNotExistsException: if account
+            does not exist
 
-        Instances of this class are dictionaries that come with additional
-        methods (see below) that allow dealing with an account and it's
-        corresponding functions.
+    Instances of this class are dictionaries that come with additional
+    methods (see below) that allow dealing with an account and it's
+    corresponding functions.
 
-        .. code-block:: python
+    .. code-block:: python
 
-            from aio.account import Account
-            account = await Account("init0")
-            print(account)
+        from aio.account import Account
+        account = await Account("init0")
+        print(account)
 
-        .. note:: This class comes with its own caching function to reduce the
-                  load on the API server. Instances of this class can be
-                  refreshed with ``await Account.refresh()``.
+    .. note:: This class comes with its own caching function to reduce the
+              load on the API server. Instances of this class can be
+              refreshed with ``await Account.refresh()``.
 
     """
 
@@ -51,8 +51,7 @@ class Account(BlockchainObject, SyncAccount):
         await BlockchainObject.__init__(self, *args, **kwargs)
 
     async def refresh(self):
-        """ Refresh/Obtain an account's data from the API server
-        """
+        """Refresh/Obtain an account's data from the API server"""
         import re
 
         if re.match(r"^1\.2\.[0-9]*$", self.identifier):
@@ -92,8 +91,8 @@ class Account(BlockchainObject, SyncAccount):
 
     @property
     async def balances(self):
-        """ List balances of an account. This call returns instances of
-            :class:`amount.Amount`.
+        """List balances of an account. This call returns instances of
+        :class:`amount.Amount`.
         """
         balances = await self.blockchain.rpc.get_account_balances(self["id"], [])
         return [
@@ -103,8 +102,8 @@ class Account(BlockchainObject, SyncAccount):
         ]
 
     async def balance(self, symbol):
-        """ Obtain the balance of a specific Asset. This call returns instances of
-            :class:`amount.Amount`.
+        """Obtain the balance of a specific Asset. This call returns instances of
+        :class:`amount.Amount`.
         """
         if isinstance(symbol, dict) and "symbol" in symbol:
             symbol = symbol["symbol"]
@@ -115,26 +114,26 @@ class Account(BlockchainObject, SyncAccount):
         return await self.amount_class(0, symbol, blockchain_instance=self.blockchain)
 
     async def history(self, first=0, last=0, limit=-1, only_ops=[], exclude_ops=[]):
-        """ Returns a generator for individual account transactions. The
-            latest operation will be first. This call can be used in a
-            ``for`` loop.
+        """Returns a generator for individual account transactions. The
+        latest operation will be first. This call can be used in a
+        ``for`` loop.
 
-            :param int first: sequence number of the first
-                transaction to return (*optional*)
-            :param int last: sequence number of the last
-                transaction to return (*optional*)
-            :param int limit: limit number of transactions to
-                return (*optional*)
-            :param array only_ops: Limit generator by these
-                operations (*optional*)
-            :param array exclude_ops: Exclude these operations from
-                generator (*optional*).
+        :param int first: sequence number of the first
+            transaction to return (*optional*)
+        :param int last: sequence number of the last
+            transaction to return (*optional*)
+        :param int limit: limit number of transactions to
+            return (*optional*)
+        :param array only_ops: Limit generator by these
+            operations (*optional*)
+        :param array exclude_ops: Exclude these operations from
+            generator (*optional*).
 
-            ... note::
-                only_ops and exclude_ops takes an array of strings:
-                The full list of operation ID's can be found in
-                operationids.py.
-                Example: ['transfer', 'fill_order']
+        ... note::
+            only_ops and exclude_ops takes an array of strings:
+            The full list of operation ID's can be found in
+            operationids.py.
+            Example: ['transfer', 'fill_order']
         """
         _limit = 100
         cnt = 0
@@ -175,52 +174,48 @@ class Account(BlockchainObject, SyncAccount):
             first = int(txs[-1]["id"].split(".")[2])
 
     async def upgrade(self):  # pragma: no cover
-        """ Upgrade account to life time member
-        """
+        """Upgrade account to life time member"""
         assert callable(self.blockchain.upgrade_account)
         return await self.blockchain.upgrade_account(account=self)
 
     async def whitelist(self, account):  # pragma: no cover
-        """ Add an other account to the whitelist of this account
-        """
+        """Add an other account to the whitelist of this account"""
         assert callable(self.blockchain.account_whitelist)
         return await self.blockchain.account_whitelist(
             account, lists=["white"], account=self
         )
 
     async def blacklist(self, account):  # pragma: no cover
-        """ Add an other account to the blacklist of this account
-        """
+        """Add an other account to the blacklist of this account"""
         assert callable(self.blockchain.account_whitelist)
         return await self.blockchain.account_whitelist(
             account, lists=["black"], account=self
         )
 
     async def nolist(self, account):  # pragma: no cover
-        """ Remove an other account from any list of this account
-        """
+        """Remove an other account from any list of this account"""
         assert callable(self.blockchain.account_whitelist)
         return await self.blockchain.account_whitelist(account, lists=[], account=self)
 
 
 @asyncinit
 class AccountUpdate(SyncAccountUpdate):
-    """ This purpose of this class is to keep track of account updates
-        as they are pushed through by :class:`notify.Notify`.
+    """This purpose of this class is to keep track of account updates
+    as they are pushed through by :class:`notify.Notify`.
 
-        Instances of this class are dictionaries and take the following
-        form:
+    Instances of this class are dictionaries and take the following
+    form:
 
-        ... code-block: js
+    ... code-block: js
 
-            {'id': '2.6.29',
-             'lifetime_fees_paid': '44261516129',
-             'most_recent_op': '2.9.0',
-             'owner': '1.2.29',
-             'pending_fees': 0,
-             'pending_vested_fees': 16310,
-             'total_core_in_orders': '6788845277634',
-             'total_ops': 0}
+        {'id': '2.6.29',
+         'lifetime_fees_paid': '44261516129',
+         'most_recent_op': '2.9.0',
+         'owner': '1.2.29',
+         'pending_fees': 0,
+         'pending_vested_fees': 16310,
+         'total_core_in_orders': '6788845277634',
+         'total_ops': 0}
 
     """
 
@@ -241,9 +236,9 @@ class AccountUpdate(SyncAccountUpdate):
 
     @property
     async def account(self):
-        """ In oder to obtain the actual
-            :class:`account.Account` from this class, you can
-            use the ``account`` attribute.
+        """In oder to obtain the actual
+        :class:`account.Account` from this class, you can
+        use the ``account`` attribute.
         """
         account = await self.account_class(
             self["owner"], blockchain_instance=self.blockchain
