@@ -4,52 +4,52 @@ from .instance import AbstractBlockchainInstanceProvider
 
 
 class Amount(dict, AbstractBlockchainInstanceProvider):
-    """ This class deals with Amounts of any asset to simplify dealing with the tuple::
+    """This class deals with Amounts of any asset to simplify dealing with the tuple::
 
-            (amount, asset)
+        (amount, asset)
 
-        :param list args: Allows to deal with different representations of an amount
-        :param float amount: Let's create an instance with a specific amount
-        :param str asset: Let's you create an instance with a specific asset (symbol)
-        :param instance blockchain_instance: instance to use when accesing a RPC
-        :returns: All data required to represent an Amount/Asset
-        :rtype: dict
-        :raises ValueError: if the data provided is not recognized
+    :param list args: Allows to deal with different representations of an amount
+    :param float amount: Let's create an instance with a specific amount
+    :param str asset: Let's you create an instance with a specific asset (symbol)
+    :param instance blockchain_instance: instance to use when accesing a RPC
+    :returns: All data required to represent an Amount/Asset
+    :rtype: dict
+    :raises ValueError: if the data provided is not recognized
 
-        .. code-block:: python
+    .. code-block:: python
 
-            from peerplays.amount import Amount
-            from peerplays.asset import Asset
-            a = Amount("1 USD")
-            b = Amount(1, "USD")
-            c = Amount("20", self.asset_class("USD"))
-            a + b
-            a * 2
-            a += b
-            a /= 2.0
+        from peerplays.amount import Amount
+        from peerplays.asset import Asset
+        a = Amount("1 USD")
+        b = Amount(1, "USD")
+        c = Amount("20", self.asset_class("USD"))
+        a + b
+        a * 2
+        a += b
+        a /= 2.0
 
-        Way to obtain a proper instance:
+    Way to obtain a proper instance:
 
-            * ``args`` can be a string, e.g.:  "1 USD"
-            * ``args`` can be a dictionary containing ``amount`` and ``asset_id``
-            * ``args`` can be a dictionary containing ``amount`` and ``asset``
-            * ``args`` can be a list of a ``float`` and ``str`` (symbol)
-            * ``args`` can be a list of a ``float`` and a :class:`.asset.Asset`
-            * ``amount`` and ``asset`` are defined manually
+        * ``args`` can be a string, e.g.:  "1 USD"
+        * ``args`` can be a dictionary containing ``amount`` and ``asset_id``
+        * ``args`` can be a dictionary containing ``amount`` and ``asset``
+        * ``args`` can be a list of a ``float`` and ``str`` (symbol)
+        * ``args`` can be a list of a ``float`` and a :class:`.asset.Asset`
+        * ``amount`` and ``asset`` are defined manually
 
-        An instance is a dictionary and comes with the following keys:
+    An instance is a dictionary and comes with the following keys:
 
-            * ``amount`` (float)
-            * ``symbol`` (str)
-            * ``asset`` (instance of :class:`.asset.Asset`)
+        * ``amount`` (float)
+        * ``symbol`` (str)
+        * ``asset`` (instance of :class:`.asset.Asset`)
 
-        Instances of this class can be used in regular mathematical expressions
-        (``+-*/%``) such as:
+    Instances of this class can be used in regular mathematical expressions
+    (``+-*/%``) such as:
 
-        .. code-block:: python
+    .. code-block:: python
 
-            Amount("1 USD") * 2
-            Amount("15 GOLD") + Amount("0.5 GOLD")
+        Amount("1 USD") * 2
+        Amount("15 GOLD") + Amount("0.5 GOLD")
     """
 
     def __init__(self, *args, **kwargs):
@@ -132,8 +132,7 @@ class Amount(dict, AbstractBlockchainInstanceProvider):
         self["amount"] = float(self.get("amount", 0.0))
 
     def copy(self):
-        """ Copy the instance and make sure not to use a reference
-        """
+        """Copy the instance and make sure not to use a reference"""
         return self.__class__(
             amount=self["amount"],
             asset=self["asset"].copy(),
@@ -142,14 +141,12 @@ class Amount(dict, AbstractBlockchainInstanceProvider):
 
     @property
     def amount(self):
-        """ Returns the amount as float
-        """
+        """Returns the amount as float"""
         return self["amount"]
 
     @property
     def symbol(self):
-        """ Returns the symbol of the asset
-        """
+        """Returns the symbol of the asset"""
         return self["symbol"]
 
     def tuple(self):
@@ -157,8 +154,7 @@ class Amount(dict, AbstractBlockchainInstanceProvider):
 
     @property
     def asset(self):
-        """ Returns the asset as instance of :class:`.asset.Asset`
-        """
+        """Returns the asset as instance of :class:`.asset.Asset`"""
         if not self["asset"]:
             self["asset"] = self.asset_class(
                 self["symbol"], blockchain_instance=self.blockchain
