@@ -8,8 +8,7 @@ timeFormat = "%Y-%m-%dT%H:%M:%S"
 
 
 def formatTime(t):
-    """ Properly Format Time for permlinks
-    """
+    """Properly Format Time for permlinks"""
     if isinstance(t, float):
         return datetime.utcfromtimestamp(t).strftime(timeFormat)
     if isinstance(t, datetime):
@@ -17,8 +16,7 @@ def formatTime(t):
 
 
 def formatTimeString(t):
-    """ Properly Format Time for permlinks
-    """
+    """Properly Format Time for permlinks"""
     try:
         return datetime.strptime(t, timeFormat)
     except Exception:
@@ -27,12 +25,12 @@ def formatTimeString(t):
 
 
 def formatTimeFromNow(secs=None):
-    """ Properly Format Time that is `x` seconds in the future
+    """Properly Format Time that is `x` seconds in the future
 
-        :param int secs: Seconds to go in the future (`x>0`) or the
-                         past (`x<0`)
-        :return: Properly formated time for Graphene (`%Y-%m-%dT%H:%M:%S`)
-        :rtype: str
+    :param int secs: Seconds to go in the future (`x>0`) or the
+                     past (`x<0`)
+    :return: Properly formated time for Graphene (`%Y-%m-%dT%H:%M:%S`)
+    :rtype: str
 
     """
     return datetime.utcfromtimestamp(time.time() + int(secs or 0)).strftime(timeFormat)
@@ -40,7 +38,7 @@ def formatTimeFromNow(secs=None):
 
 def parse_time(block_time):
     """Take a string representation of time from the blockchain, and parse it
-       into datetime object.
+    into datetime object.
     """
     return formatTimeString(block_time).replace(tzinfo=timezone.utc)
 
